dprintf

Macro dprintf 

macro_rules! dprintf {
    (CRITICAL, $($arg:tt)*) => { ... };
    (ALWAYS, $($arg:tt)*) => { ... };
    (INFO, $($arg:tt)*) => { ... };
    (SPEW, $($arg:tt)*) => { ... };
    ($level:expr, $($arg:tt)*) => { ... };
}
Formats and prints a debug message if the global debug print level is greater than or equal to the specified level.

Equivalent to C++ dprintf.

Examples

dprintf!(INFO, "initialized with value {}\n", val);