kernel_oops

Macro kernel_oops 

macro_rules! kernel_oops {
    ($fmt:literal, $($arg:tt)*) => { ... };
}
A kprint-like macro which prepend’s the user’s message with the special “ZIRCON KERNEL OOPS” tag. Automated builds look for tags like this and consider their presence to indicate test failures, even if the higher level test framework code thinks the test passed.

A kernel OOPS indicates the presence of a bug, however, the bug may not be in the kernel itself.

Examples

kernel_oops!("value {} is out of range", val);