macro_rules! trace_exit_obj {
($obj:expr) => { ... };
($name:expr, $obj:expr) => { ... };
}Expand description
Prints function exit along with the object pointer (self or reference).
Equivalent to C++ TRACE_EXIT_OBJ.
macro_rules! trace_exit_obj {
($obj:expr) => { ... };
($name:expr, $obj:expr) => { ... };
}Prints function exit along with the object pointer (self or reference).
Equivalent to C++ TRACE_EXIT_OBJ.